@@ -1,7 +1,7 @@
 pub mod instruction;
-pub mod pda;
 
 pub use cronos_program::errors;
+pub use cronos_program::pda;
 pub use cronos_program::state as account;
 
 // Export current solana-program types for downstream users who may also be
